@@ -1,12 +1,12 @@
 /*
- * Copyright (c) 2000-2001 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2000-2001, 2003 Sendmail, Inc. and its suppliers.
  *	All rights reserved.
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the LICENSE file which can be found at the top level of
  * the sendmail distribution.
  *
- *	$Id: sm_os_aix.h,v 1.9 2001/10/09 23:12:13 ca Exp $
+ *	$Id: sm_os_aix.h,v 1.9.2.1 2003/04/28 23:11:07 ca Exp $
  */
 
 /*
@@ -33,3 +33,7 @@
 #  endif /* SM_CONF_SYSLOG */
 # endif /* ! _AIX4 */
 #endif /* _AIX3 */
+
+#if _AIX5 >= 50200
+# define SM_CONF_LONGLONG	1
+#endif /* _AIX5 >= 50200 */
